@@ -1,4 +1,4 @@
-// $Id: genres.h,v 1.10 2006/08/23 20:27:52 khlut Exp $
+// $Id: genres.h,v 1.11 2006/09/21 18:20:53 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -79,6 +79,8 @@ typedef struct {
   PRLock* lock;
   NPP instance;
   enum {Init, Running, Cancelling} status;
+  int printmode;
+  FILE * printfile;
   int autoclose;
 } PD;
 
